==> haskell-skylighting-format-ansi-0.1-116-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-FvnFm8H4uyB5znks7vTRNU
key:                  skylighting-format-ansi-0.1-FvnFm8H4uyB5znks7vTRNU
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  8af7d0ddd1e9949c2a757ea643836f75
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-FvnFm8H4uyB5znks7vTRNU
depends:
    ansi-terminal-0.11.4-6jSb6ZqnQv5806EReMBETJ base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-G4BaZUtOzBhJbWQ5oHmHiA
    containers-0.6.5.1 skylighting-core-0.14-BzqlWbZbHEV8cQATNhXW5s
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-117-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-GkVwN3PSk1N1H3bT6ERyTK
key:                  skylighting-format-ansi-0.1-GkVwN3PSk1N1H3bT6ERyTK
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  33308a9e94bb085b629003941e9ef1b6
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-GkVwN3PSk1N1H3bT6ERyTK
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-Lb0j5FHWynL92WxSgZCtF8
    containers-0.6.5.1 skylighting-core-0.14-G627Fh4sueu1RyTRIOQ6ye
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
